Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(880)

Unified Diff: third_party/WebKit/Source/modules/netinfo/NetworkInformation.h

Issue 2941713002: NetInfo: Return HTTP layer metrics instead of transport layer (Closed)
Patch Set: ps Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/netinfo/NetworkInformation.h
diff --git a/third_party/WebKit/Source/modules/netinfo/NetworkInformation.h b/third_party/WebKit/Source/modules/netinfo/NetworkInformation.h
index af476b7d904da84bec6e825d15342f6d6665c7b4..3cff35f9c02af511ff516ba2624c772461a4e87b 100644
--- a/third_party/WebKit/Source/modules/netinfo/NetworkInformation.h
+++ b/third_party/WebKit/Source/modules/netinfo/NetworkInformation.h
@@ -83,9 +83,9 @@ class NetworkInformation final
// network in use.
WebEffectiveConnectionType effective_type_;
// Transport RTT estimate. Rounded off to the nearest 25 msec. Touched only on
// context thread.
- unsigned long transport_rtt_msec_;
+ unsigned long http_rtt_msec_;
// Downlink throughput estimate. Rounded off to the nearest 25 kbps. Touched
// only on context thread.
« no previous file with comments | « content/browser/net_info_browsertest.cc ('k') | third_party/WebKit/Source/modules/netinfo/NetworkInformation.cpp » ('j') | no next file with comments »
@@ -83,9 +83,9 @@ class NetworkInformation final
// network in use.
WebEffectiveConnectionType effective_type_;
- // Transport RTT estimate. Rounded off to the nearest 25 msec. Touched only on
+ // HTTP RTT estimate. Rounded off to the nearest 25 msec. Touched only on
// context thread.

Powered by Google App Engine
This is Rietveld 408576698